package pro.litvinovg.w2phtml.gui;

import static pro.litvinovg.w2phtml.gui.Contstants.*;

import java.awt.Component;
import java.awt.EventQueue;
import java.awt.GridLayout;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.HashMap;

import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.LayoutStyle.ComponentPlacement;
import javax.swing.UIManager;

import com.sun.star.uno.XComponentContext;

public class ConfigurationWindow extends JFrame {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	private static JFrame singleFrame = null;


	public static JFrame getSingleFrame() {
		return singleFrame;
	}

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {

		runGUI(null);
	}

	private XComponentContext context;
	private Localizer localizer;
	private PreferencesStorage storage;

	/**
	 * Create the application.
	 */
	public ConfigurationWindow() {
		this.localizer = new Localizer();
		initializePreferences();
		setTitle(localizer.getTranslation(CONVERTER_TITLE_LABEL));
		setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
		setIconImage(Toolkit.getDefaultToolkit().getImage(ConfigurationWindow.class.getResource("/pro/litvinovg/w2phtml/gui/resources/w2phtml.png")));
		initComponents();
		createEvents();
	}
	
	public ConfigurationWindow(XComponentContext context, ODTDocument doc) {
		this.context = context;
		this.localizer = new Localizer();
		initializePreferences();
		storage.setSourceFileName(doc.getFileName());
		setTitle(localizer.getTranslation(CONVERTER_TITLE_LABEL));
		setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
		setIconImage(Toolkit.getDefaultToolkit().getImage(ConfigurationWindow.class.getResource("/pro/litvinovg/w2phtml/gui/resources/w2phtml.png")));
		initComponents();
		createEvents();
	}
	
	private void initializePreferences() {
		storage = new PreferencesStorage();
	}

	private void createEvents() {
		// TODO Auto-generated method stub
		
	}

	private void initComponents() {
		getContentPane().setLayout(new GridLayout(1, 0, 0, 0));
		JTabbedPane tabbedPane = new JTabbedPane(JTabbedPane.LEFT);
		getContentPane().add(tabbedPane);
		PanelFactory panelFactory = new PanelFactory(localizer, storage, tabbedPane);
		panelFactory.createPanels();
		JPanel epub = panelFactory.createPanel(EPUB);
		JPanel rdf = panelFactory.createPanel(RDF);
		JPanel html = panelFactory.createPanel(HTML); 
	}

	public static void runGUI(XComponentContext context) {
		ODTDocument doc = new ODTDocument(context);
		if (singleFrame != null) {
			singleFrame.dispose();
		}
			try {
				UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
			} catch (Throwable e) {
				String message = e.getLocalizedMessage();
				JOptionPane.showMessageDialog(singleFrame, message);	
			} 
			EventQueue.invokeLater(new Runnable() {
				public void run() {
					try {
						ConfigurationWindow frame = new ConfigurationWindow(context,doc);
						singleFrame = frame;
						frame.setBounds(100, 100, 1100, 800);
						frame.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
						frame.setVisible(true);

					} catch (Throwable e) {
						String message = e.getLocalizedMessage();
						e.printStackTrace();
						JOptionPane.showMessageDialog(singleFrame, message);	
					} 
				}
			});	
		
	}
}
