package pro.litvinovg.w2phtml.gui;

import static pro.litvinovg.w2phtml.gui.Contstants.*;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.HashMap;

import javax.swing.GroupLayout;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JOptionPane;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.swing.GroupLayout.Alignment;
import javax.swing.LayoutStyle.ComponentPlacement;

public class ControlPanel extends BasePanel {
	private static final Logger logger = LoggerFactory.getLogger(ControlPanel.class);
	private PreferencesStorage storage;
	private String configName;
	private String configType;
	private PanelFactory factory = null;
	public void setFactory(PanelFactory factory) {
		this.factory = factory;
	}
	public ControlPanel(HashMap<String,Component> configuration,Localizer localizer, PreferencesStorage storage, String configName, String configType) {
		super(localizer);
		this.storage = storage;
		this.configName = configName;
		this.configType = configType;
		
		JButton btn_Exit = new JButton(localizer.getTranslation(BUTTON_EXIT_LABEL));
		btn_Exit.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				ConfigurationWindow.getSingleFrame().setVisible(false);
				ConfigurationWindow.getSingleFrame().dispose();
			}
		});
		
		JButton btn_SaveAs = new JButton(localizer.getTranslation(BUTTON_SAVEAS_LABEL));
		btn_SaveAs.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent actionEvent) {
				String newConfigName = JOptionPane.showInputDialog(localizer.getTranslation(ENTER_NEW_CONFIG_NAME));
				if (newConfigName == null || newConfigName.isEmpty()) {
					return;
				}
				if (storage.has(newConfigName)) {
					JOptionPane.showMessageDialog(ConfigurationWindow.getSingleFrame(), localizer.getTranslation(CONFIG_NAME_IS_ALREADY_IN_USE));
					return;
				}
				UIPreferences newPrefs = storage.get(configName).clone();
				newPrefs.updateFrom(configuration);
				storage.put(newConfigName, newPrefs);
				if (factory != null) {
					factory.createPanel(newConfigName);
				}
				storage.save();
			}
		});
		
		JButton btn_Save = new JButton(localizer.getTranslation(BUTTON_SAVE_LABEL));
		btn_Save.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent actionEvent) {
				storage.get(configName).updateFrom(configuration);
				storage.save();
				JOptionPane.showMessageDialog(ConfigurationWindow.getSingleFrame(), localizer.getTranslation(SUCCESSFULLY_SAVED));
			}
		});
		
		JButton btn_delete = new JButton(localizer.getTranslation(BUTTON_DELETE_LABEL));
		btn_delete.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent actionEvent) {
				storage.remove(configName);
				factory.removeCurPanel();
				storage.save();
			}
		});
		
		if (configName == HTML || configName == RDF || configName == EPUB) {
			btn_Save.setVisible(false);
			btn_delete.setVisible(false);

		}
		JButton btn_startConversion = new JButton(localizer.getTranslation(BUTTON_CONVERT_LABEL));
		btn_startConversion.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent actionEvent) {
				try {
				ConversionExecutor executor = new ConversionExecutor(configuration, ConfigurationWindow.getSingleFrame());
					executor.convert();
				} catch(Throwable e) {
					StringWriter errors = new StringWriter();
					e.printStackTrace(new PrintWriter(errors));
					JOptionPane.showMessageDialog(ConfigurationWindow.getSingleFrame(),errors.toString());
				}
			}
			
		});
		
		GroupLayout gl_panel_control = new GroupLayout(this);
		gl_panel_control.setHorizontalGroup(
			gl_panel_control.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_panel_control.createSequentialGroup()
					.addGap(83)
					.addComponent(btn_Exit, GroupLayout.PREFERRED_SIZE, 100, GroupLayout.PREFERRED_SIZE)
					.addGap(18)
					.addComponent(btn_SaveAs, GroupLayout.PREFERRED_SIZE, 140, GroupLayout.PREFERRED_SIZE)
					.addGap(18)
					.addComponent(btn_Save, GroupLayout.PREFERRED_SIZE, 120, GroupLayout.PREFERRED_SIZE)
					.addPreferredGap(ComponentPlacement.UNRELATED)
					.addComponent(btn_delete, GroupLayout.PREFERRED_SIZE, 120, GroupLayout.PREFERRED_SIZE)
					.addPreferredGap(ComponentPlacement.RELATED)
					.addComponent(btn_startConversion, GroupLayout.PREFERRED_SIZE, 100, GroupLayout.PREFERRED_SIZE)
					.addContainerGap(86, Short.MAX_VALUE))
		);
		gl_panel_control.setVerticalGroup(
			gl_panel_control.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_panel_control.createSequentialGroup()
					.addContainerGap()
					.addGroup(gl_panel_control.createParallelGroup(Alignment.TRAILING, false)
						.addComponent(btn_startConversion, Alignment.LEADING, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
						.addComponent(btn_delete, Alignment.LEADING, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
						.addComponent(btn_SaveAs, Alignment.LEADING, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
						.addComponent(btn_Save, Alignment.LEADING, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
						.addComponent(btn_Exit, Alignment.LEADING, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
					.addContainerGap(54, Short.MAX_VALUE))
		);
						
		this.setLayout(gl_panel_control);
	}
}
